package br.com.tcc.safeson.safeson;

import android.content.Intent;
import android.graphics.Color;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;

import com.google.android.gms.auth.api.Auth;
import com.google.android.gms.auth.api.signin.GoogleSignIn;
import com.google.android.gms.auth.api.signin.GoogleSignInAccount;
import com.google.android.gms.auth.api.signin.GoogleSignInClient;
import com.google.android.gms.auth.api.signin.GoogleSignInOptions;
import com.google.android.gms.auth.api.signin.GoogleSignInResult;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.ApiException;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.common.api.OptionalPendingResult;
import com.google.android.gms.tasks.Task;
import com.google.maps.GeoApiContext;

import br.com.tcc.safeson.safeson.actions.BaseMessage;
import br.com.tcc.safeson.safeson.actions.EventLogin.EventLoginGoogleMessage;
import br.com.tcc.safeson.safeson.login.UserLogged;
import br.com.tcc.safeson.safeson.models.User;
import br.com.tcc.safeson.safeson.socket.SocketConnection;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class LoginActivity extends AppCompatActivity implements GoogleApiClient.OnConnectionFailedListener {
    private static final int RC_SIGN_IN = 9001;

    private GoogleSignInClient mGoogleSignInClient;
    private GoogleSignInOptions gso;
    private GoogleApiClient googleApiClient;
    private SocketConnection socket = SocketConnection.main;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login);
        getWindow().setStatusBarColor(Color.GRAY);

        ButterKnife.bind(this);

        GoogleSignInOptions googleSignInOptions = new GoogleSignInOptions.Builder(GoogleSignInOptions.DEFAULT_SIGN_IN).requestEmail().build();
        googleApiClient = new GoogleApiClient.Builder(this)
                .enableAutoManage(this, this)
                .addApi(Auth.GOOGLE_SIGN_IN_API, googleSignInOptions).build();
        socket.connect();

        gso = new GoogleSignInOptions.Builder(GoogleSignInOptions.DEFAULT_SIGN_IN)
                .requestIdToken(getString(R.string.server_client_id))
                .requestEmail()
                .build();
        mGoogleSignInClient = GoogleSignIn.getClient(this, gso);

    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        if (requestCode == RC_SIGN_IN) {
            Task<GoogleSignInAccount> task = GoogleSignIn.getSignedInAccountFromIntent(data);
            try {
                GoogleSignInAccount account = task.getResult(ApiException.class);

                sendLoginGoogleMessage(account.getIdToken());
            } catch (ApiException e) {
                System.out.println("Error - Google sign in " + e);
            }
        }
    }

    @Override
    protected void onStart() {
        super.onStart();

        OptionalPendingResult<GoogleSignInResult> opr = Auth.GoogleSignInApi.silentSignIn(googleApiClient);
        if (opr.isDone()) {
            GoogleSignInResult result = opr.get();
            handleSingInResult(result);
        } else {
            opr.setResultCallback(googleSignInResult -> handleSingInResult(googleSignInResult));
        }
    }

    private void sendLoginGoogleMessage(String idToken) {
        socket.sendSingleMessage(
            new BaseMessage("event.login.google",
                    new EventLoginGoogleMessage(idToken)
            ), User.class
        ).subscribe(
            (res) -> {
                User result = (User) res.result;
                ((UserLogged)(getApplicationContext())).set(result);

                Intent intent = new Intent(this, MainActivity.class);
                startActivity(intent);
                finish();
            },
            (err) -> {
                System.out.println(err);
            }
        );
    }

    @OnClick(R.id.sign_google) void onClickGoogle() {
        socket.connect();
        Intent signInIntent = mGoogleSignInClient.getSignInIntent();
        startActivityForResult(signInIntent, RC_SIGN_IN);
    }

    @Override
    public void onConnectionFailed(@NonNull ConnectionResult connectionResult) {

    }

    private void handleSingInResult(GoogleSignInResult result) {
        if (result.isSuccess()) {
            GoogleSignInAccount account = result.getSignInAccount();
            sendLoginGoogleMessage(account.getIdToken());
        }
    }
}
