package br.com.tcc.safeson.safeson.activity;

import android.support.design.widget.FloatingActionButton;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;

import com.baoyz.swipemenulistview.SwipeMenuListView;

import java.lang.reflect.Array;
import java.util.ArrayList;

import br.com.tcc.safeson.safeson.R;
import br.com.tcc.safeson.safeson.actions.BaseMessage;
import br.com.tcc.safeson.safeson.actions.EventFriends.EventFriendGetMessage;
import br.com.tcc.safeson.safeson.actions.EventFriends.EventFriendGetResult;
import br.com.tcc.safeson.safeson.adapter.FriendListCell;
import br.com.tcc.safeson.safeson.components.ActivitiesComponents;
import br.com.tcc.safeson.safeson.login.UserLogged;
import br.com.tcc.safeson.safeson.models.Grupo;
import br.com.tcc.safeson.safeson.models.User;
import br.com.tcc.safeson.safeson.socket.SocketConnection;

public class GroupActivity extends AppCompatActivity {
    ListView lwFriends;
    ArrayList<User> friends;
    Button salvarBtn;
    EditText txtGroupName;
    Grupo grupoAtual;

    private SocketConnection socket = SocketConnection.main;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_group);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);

        grupoAtual = (Grupo) getIntent().getSerializableExtra("grupo");

        ActivitiesComponents activitiesComponents = new ActivitiesComponents(GroupActivity.this);

        lwFriends = findViewById(R.id.lsFriends);
        lwFriends.setOnItemClickListener((adapterView, view, i, l) -> {
            CheckBox cb = (CheckBox)view.findViewById(R.id.checkbox);
            cb.setChecked(!cb.isChecked());
        });

        txtGroupName = findViewById(R.id.txtGroupName);

        if (grupoAtual != null) {
            txtGroupName.setText(grupoAtual.nome);
        }

        salvarBtn = findViewById(R.id.salvarGroupBtn);
        salvarBtn.setOnClickListener((view) -> {
            if (txtGroupName == null
                    || txtGroupName.getText().toString().equals("")
                    || txtGroupName.getText().toString() == null)
            {
                Toast.makeText(this, "Digite um nome para o grupo", Toast.LENGTH_SHORT).show();
                return;
            }

            ArrayList<String> socialIds = new ArrayList<>();

            for (int i = 0; i < lwFriends.getAdapter().getCount(); i++) {
                friends.get(i).created = ((CheckBox) getViewByPosition(i, lwFriends).findViewById(R.id.checkbox)).isChecked();
            }

            for (User u : friends) {
                if (u.created) {
                    socialIds.add(u.socialId);
                }
            }

            if (socialIds.isEmpty()) {
                Toast.makeText(this, "Você precisa adicionar alguem ao seu grupo", Toast.LENGTH_SHORT).show();
                return;
            }

            Grupo grupo = new Grupo(txtGroupName.getText().toString(), socialIds, UserLogged.get().socialId);

            if (grupoAtual == null) {
                socket.sendSingleMessage(
                        new BaseMessage("event.group.add", grupo),
                        Grupo.class
                ).subscribe(
                        (res) -> {
                            runOnUiThread(() -> {
                                Toast.makeText(this, "Grupo criado", Toast.LENGTH_SHORT).show();
                                startActivity(activitiesComponents.callScreen(this, GroupsActivity.class));
                                finish();
                            });
                        },
                        (err) -> {
                            System.out.println("Erro ao adicionar um novo grupo");
                            System.out.println(err);
                        }
                );
            } else {
                grupoAtual.nome = txtGroupName.getText().toString();
                grupoAtual.membros = socialIds;
                grupoAtual.socialId = UserLogged.get().socialId;

                socket.sendSingleMessage(
                    new BaseMessage("event.group.update", grupoAtual),
                    Grupo.class
                ).subscribe(
                    (res) -> {
                        runOnUiThread(() -> {
                            Toast.makeText(this, "Grupo atualizado", Toast.LENGTH_SHORT).show();
                            startActivity(activitiesComponents.callScreen(this, GroupsActivity.class));
                            finish();
                        });
                    },
                    (err) -> {
                        System.out.println("Erro ao atualizar o grupo");
                        System.out.println(err);
                    }
                );
            }
        });
        friends = new ArrayList<>();
        EventFriendGetMessage msg = new EventFriendGetMessage(UserLogged.get().socialId, null);

        socket.sendSingleMessage(
                new BaseMessage("event.friends.get", msg),
                EventFriendGetResult.class
        ).subscribe(
                (res) -> {
                    friends = ((EventFriendGetResult) res.result).res;
                    runOnUiThread(()-> {
                        if (grupoAtual == null) {
                            FriendListCell adapter = new FriendListCell(this, friends, 2);
                            lwFriends.setAdapter(adapter);
                            return;
                        }

                        ArrayList<User> selecionados = new ArrayList<>();

                        for (String membroId : grupoAtual.membros) {
                            for (User user : friends) {
                                if (user.socialId.equals(membroId)) {
                                    selecionados.add(user);
                                }
                            }
                        }

                        FriendListCell adapter = new FriendListCell(this, friends, selecionados, 2);
                        lwFriends.setAdapter(adapter);
                    });
                },
                (err) -> {
                    System.out.println("Errou");
                    System.out.println(err);
                }
        );
    }

    public View getViewByPosition(int pos, ListView listView) {
        final int firstListItemPosition = listView.getFirstVisiblePosition();
        final int lastListItemPosition = firstListItemPosition + listView.getChildCount() - 1;

        if (pos < firstListItemPosition || pos > lastListItemPosition ) {
            return listView.getAdapter().getView(pos, null, listView);
        } else {
            final int childIndex = pos - firstListItemPosition;
            return listView.getChildAt(childIndex);
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // handle arrow click here
        if (item.getItemId() == android.R.id.home) {
            finish();
        }
        return super.onOptionsItemSelected(item);
    }
}
