package br.com.tcc.safeson.safeson.activity;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.baoyz.swipemenulistview.SwipeMenuListView;

import java.util.ArrayList;

import br.com.tcc.safeson.safeson.R;
import br.com.tcc.safeson.safeson.actions.BaseMessage;
import br.com.tcc.safeson.safeson.actions.EventInvite.EventInviteGetMessage;
import br.com.tcc.safeson.safeson.actions.EventInvite.EventInviteGetResult;
import br.com.tcc.safeson.safeson.actions.EventInvite.EventInviteRespondMessage;
import br.com.tcc.safeson.safeson.adapter.BtnClickListener;
import br.com.tcc.safeson.safeson.adapter.FriendListCell;
import br.com.tcc.safeson.safeson.adapter.InviteListCell;
import br.com.tcc.safeson.safeson.login.UserLogged;
import br.com.tcc.safeson.safeson.models.Invite;
import br.com.tcc.safeson.safeson.models.User;
import br.com.tcc.safeson.safeson.socket.SocketConnection;

public class NotificationsActivity extends AppCompatActivity {
    private SocketConnection socket = SocketConnection.main;

    private ListView list;
    private ArrayList<Invite> invites;
    private InviteListCell adapter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_notifications);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);

        list = findViewById(R.id.listNotifications);
        invites = new ArrayList<>();

        socket.sendSingleMessage(
            new BaseMessage(
            "event.invite.get", new EventInviteGetMessage(UserLogged.get().socialId)
            ),
            EventInviteGetResult.class
        ).subscribe(
            res -> {
                invites = ((EventInviteGetResult) res.result).res;

                runOnUiThread(() -> {
                    if (invites.size() == 0) {
                        Toast.makeText(this, "Não há nenhuma notificação para você", Toast.LENGTH_SHORT).show();
                    }
                    adapter = new InviteListCell(this, invites,
                        this::aceitar,
                        this::recusar
                    );
                    list.setAdapter(adapter);
                });
            },
            err -> {
                System.out.println("Erro recebendo convites -> " + err);
                runOnUiThread(() -> {
                    Toast.makeText(this, "Não há nenhuma notificação para você", Toast.LENGTH_SHORT).show();
                });
            }
        );
    }

    private void aceitar(int pos) {
        socket.sendSingleMessage(
            new BaseMessage(
                "event.invite.respond",
                new EventInviteRespondMessage(true, UserLogged.get().socialId, invites.get(pos).trajetoUuid)
            ),
            EventInviteGetResult.class
        ).subscribe(
            res -> {
                runOnUiThread(() -> {
                    Toast.makeText(this, "Convite aceito com sucesso", Toast.LENGTH_SHORT).show();
                    finish();
                    startActivity(getIntent());
                });
            },
            err -> {
                runOnUiThread(() -> {
                    Toast.makeText(this, "Falha ao aceitar convite", Toast.LENGTH_SHORT).show();
                    finish();
                    startActivity(getIntent());
                });
            }
        );
    }

    private void recusar(int pos) {
        socket.sendSingleMessage(
            new BaseMessage(
                "event.invite.respond",
                new EventInviteRespondMessage(false, UserLogged.get().socialId, invites.get(pos).trajetoUuid)
            ),
            EventInviteGetResult.class
        ).subscribe(
            res -> {
                runOnUiThread(() -> {
                    Toast.makeText(this, "Convite recusado", Toast.LENGTH_SHORT).show();
                    finish();
                    startActivity(getIntent());
                });
            },
            err -> {
                runOnUiThread(() -> {
                    Toast.makeText(this, "Falha ao recusar convite", Toast.LENGTH_SHORT).show();
                    finish();
                    startActivity(getIntent());
                });
            }
        );
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // handle arrow click here
        if (item.getItemId() == android.R.id.home) {
            finish();
        }
        return super.onOptionsItemSelected(item);
    }
}
