package br.com.tcc.safeson.safeson.activity;

import android.Manifest;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.location.Address;
import android.location.Geocoder;
import android.location.Location;
import android.os.Bundle;
import android.os.Handler;
import android.support.annotation.NonNull;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.support.design.widget.NavigationView;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.Menu;
import android.view.MenuItem;
import android.view.WindowManager;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputMethodManager;
import android.widget.AdapterView;
import android.widget.AutoCompleteTextView;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;



import com.google.android.gms.auth.api.Auth;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.common.api.PendingResult;
import com.google.android.gms.common.api.ResultCallback;
import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.location.places.AutocompletePrediction;
import com.google.android.gms.location.places.Place;
import com.google.android.gms.location.places.PlaceBuffer;
import com.google.android.gms.location.places.Places;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.LatLngBounds;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.android.gms.tasks.Task;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import br.com.tcc.safeson.safeson.actions.BaseMessage;
import br.com.tcc.safeson.safeson.adapter.MapInfoWindowAdapter;
import br.com.tcc.safeson.safeson.adapter.PlaceAutocompleteAdapter;
import br.com.tcc.safeson.safeson.models.PlaceInfo;
import br.com.tcc.safeson.safeson.socket.SocketConnection;
import br.com.tcc.safeson.safeson.R;
import butterknife.BindView;
import butterknife.ButterKnife;

public class ReportEventActivity extends AppCompatActivity
        implements OnMapReadyCallback,  GoogleApiClient.OnConnectionFailedListener, GoogleMap.OnMarkerClickListener {
    private static final String TAG_HOME = "map";

    private static final String TAG = "MapsActivity";
    private static final LatLngBounds LAT_LNG_BOUNDS = new LatLngBounds(new LatLng(-40,-168), new LatLng(71, 136));
    private static final String FINE_LOCATION = Manifest.permission.ACCESS_FINE_LOCATION;
    private static final String COURSE_LOCATION = Manifest.permission.ACCESS_COARSE_LOCATION;
    private static final int LOCATION_PERMISSION_REQUEST_CODE = 1234;
    public static final float DEFAULT_ZOOM = 15f;



    private GoogleMap mMap;

    private Boolean mapPermissionGranted = false;
    private FusedLocationProviderClient mapFusedLocationProviderClient;
    private PlaceAutocompleteAdapter mapPlaceAutocompleteAdapter;
    private GoogleApiClient googleApiClient;
    private PlaceInfo mapPlace;
    private Marker mapMarker;

    private SocketConnection socket = SocketConnection.main;
    private Handler mHandler;

    AutoCompleteTextView mapSearchText;

    @BindView(R.id.ic_gps)
    ImageView mGps;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_report_event);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);

        ButterKnife.bind(this);
        mHandler = new Handler();

        getLocationPermission();
        initSearch();

    }


    @SuppressWarnings("StatementWithEmptyBody")

    @Override
    public void onMapReady(GoogleMap googleMap) {
        mMap = googleMap;
        if (mapPermissionGranted) {
            getDeviceLocation();
            if (ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED && ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
                return;
            }
            mMap.setMyLocationEnabled(true);
            mMap.getUiSettings().setMyLocationButtonEnabled(false);

        }

        mMap.setOnMapClickListener((point) -> {
            MarkerOptions pos = new MarkerOptions().position(point);
            mMap.clear();
            searchLocationByLatLng(point);
            moveCamera(point, DEFAULT_ZOOM, mapPlace);
            socket.sendSingleMessage(
                    new BaseMessage("broadcast.my.coordinates", point),
                    LatLng.class
            ).subscribe(
                    (res) -> {
                        LatLng result = (LatLng) res.result;

                        // Result contem os objetos da classe de result
                        System.out.println(result.latitude);
                        System.out.println(result.longitude);
                    },
                    (err) -> {
                        System.out.println("Errou");
                        System.out.println(err);
                    }
            );
        });
    }

    @Override
    public void onConnectionFailed(@NonNull ConnectionResult connectionResult) {
        Toast.makeText(this,"Falha na conexão", Toast.LENGTH_LONG);
    }

    private void getLocationPermission(){
        String[] permissions = {Manifest.permission.ACCESS_FINE_LOCATION,
                Manifest.permission.ACCESS_COARSE_LOCATION};
        if(ContextCompat.checkSelfPermission(this.getApplicationContext(),
                FINE_LOCATION) == PackageManager.PERMISSION_GRANTED){
            if(ContextCompat.checkSelfPermission(this.getApplicationContext(),
                    COURSE_LOCATION) == PackageManager.PERMISSION_GRANTED){
                mapPermissionGranted = true;
                initMap();
            }else{
                ActivityCompat.requestPermissions(this, permissions, LOCATION_PERMISSION_REQUEST_CODE);

            }
        }else{
            ActivityCompat.requestPermissions(this, permissions, LOCATION_PERMISSION_REQUEST_CODE);

        }
    }
    private void initSearch(){
        mapSearchText = (AutoCompleteTextView) findViewById(R.id.txtSearch);
        mGps.setOnClickListener(view -> {
            getDeviceLocation();
        });

        mapSearchText.setOnItemClickListener(mAutocompleteClickListener);
        mapPlaceAutocompleteAdapter = new PlaceAutocompleteAdapter(this, googleApiClient,LAT_LNG_BOUNDS, null );
        mapSearchText.setAdapter(mapPlaceAutocompleteAdapter);

        mapSearchText.setOnEditorActionListener((textView, actionId, keyEvent) -> {
            if(actionId == EditorInfo.IME_ACTION_SEARCH
                    || actionId == EditorInfo.IME_ACTION_DONE
                    || keyEvent.getAction() == KeyEvent.ACTION_DOWN
                    || keyEvent.getAction() == KeyEvent.KEYCODE_ENTER){
                searchLocation();
            }
            return false;
        });

    }

    private void searchLocation() {
        String searchTerm = mapSearchText.getText().toString();
        Geocoder geocoder = new Geocoder(ReportEventActivity.this);
        List<Address> list = new ArrayList<>();
        try {
            list = geocoder.getFromLocationName(searchTerm, 1 );
        }catch (IOException e){
            Log.e(TAG, "searchLocation: IOException" + e.getMessage());
        }
        if (list.size() > 0){
            Address address = list.get(0);
            moveCamera(new LatLng(address.getLatitude(), address.getLongitude()), DEFAULT_ZOOM);


        }
    }
    private void searchLocationByLatLng(LatLng latLng) {
        Geocoder geocoder = new Geocoder(ReportEventActivity.this);
        List<Address> list = new ArrayList<>();
        try {
            list = geocoder.getFromLocation(latLng.latitude, latLng.longitude, 1);
            mapPlace = new PlaceInfo();
            mapPlace.setName(list.get(0).getFeatureName());
            mapPlace.setAddress(list.get(0).getAddressLine(0));
            mapPlace.setPhoneNumber(list.get(0).getPhone());
            mapPlace.setLatLng(latLng);
            mapPlace.setRating(-1);
        }catch (IOException e){
            Log.e(TAG, "searchLocation: IOException" + e.getMessage());
        }
        if (list.size() > 0){
            Address address = list.get(0);
            moveCamera(new LatLng(address.getLatitude(), address.getLongitude()), DEFAULT_ZOOM);


        }
    }


    private void moveCamera(LatLng latLng, float zoom) {
        Log.d(TAG, "moveCamera: moving the camera to: lat: " + latLng.latitude + ", lng: " + latLng.longitude);

        mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(latLng, zoom));

    }
    private void initMap(){
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.map);
        mapFragment.getMapAsync(ReportEventActivity.this);
    }

    private void getDeviceLocation() {
        mapFusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(this);
        try {
            if (mapPermissionGranted) {
                Task location = mapFusedLocationProviderClient.getLastLocation();
                location.addOnCompleteListener(task -> {
                    if (task.isSuccessful()) {
                        Log.d(TAG, "onComplete: found location");
                        Location currentLocation = (Location) task.getResult();

                        if (currentLocation != null)
                            moveCamera(new LatLng(currentLocation.getLatitude(), currentLocation.getLongitude()), DEFAULT_ZOOM);
                    } else {
                        Log.d(TAG, "onComplete: current location is null");
                        Toast.makeText(ReportEventActivity.this, "unable to get current location", Toast.LENGTH_SHORT).show();
                    }
                });

            }
        } catch (SecurityException e) {
            Log.e(TAG, "getDeviceLocation: SecurityException: " + e.getMessage());
        }
    }

    private AdapterView.OnItemClickListener mAutocompleteClickListener = new AdapterView.OnItemClickListener() {
        @Override
        public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
            final AutocompletePrediction item = mapPlaceAutocompleteAdapter.getItem(i);
            final String placeId = item.getPlaceId();

            PendingResult<PlaceBuffer> placeResult = Places.GeoDataApi.getPlaceById(googleApiClient, placeId);
            placeResult.setResultCallback(mapUpdatePlaceDetailsCallBack);
        }
    };

    private ResultCallback<PlaceBuffer> mapUpdatePlaceDetailsCallBack = places -> {
        if(!places.getStatus().isSuccess()){
            Log.d(TAG, "onResult: fail query complete: "+places.getStatus().toString());
            places.release();
            return;
        }
        final Place place = places.get(0);

        try {
            mapPlace = new PlaceInfo();
            mapPlace.setName(place.getName().toString());
            mapPlace.setAddress(place.getAddress().toString());
            mapPlace.setPhoneNumber(place.getPhoneNumber().toString());
            mapPlace.setId(place.getId());
            mapPlace.setWebsiteUri(place.getWebsiteUri());
            mapPlace.setLatLng(place.getLatLng());
            mapPlace.setRating(place.getRating());
            mapPlace.setAttributions(place.getAttributions().toString());

        }catch (NullPointerException e){
            Log.e(TAG, "Places param null: "+ e.getMessage() );
        }
        moveCamera(mapPlace.getLatLng(), DEFAULT_ZOOM, mapPlace);
        places.release();
    };

    private void moveCamera(LatLng latLng, float zoom, PlaceInfo placeInfo) {
        Log.d(TAG, "moveCamera: moving the camera to: lat: " + latLng.latitude + ", lng: " + latLng.longitude);
        mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(latLng, zoom));
        mMap.clear();
        mMap.setInfoWindowAdapter(new MapInfoWindowAdapter(ReportEventActivity.this));
        if(placeInfo != null){
            try {
                String snippet = getSnippet(placeInfo);
                MarkerOptions options = new MarkerOptions()
                        .position(latLng)
                        .title(placeInfo.getName())
                        .snippet(snippet);
                mapMarker = mMap.addMarker(options);
            }catch (NullPointerException e){
                Log.e(TAG, "moveCamera: Null placeInfo" + e.getMessage() );
            }

        }else{
            mMap.addMarker(new MarkerOptions().position(latLng));
        }
        mapMarker.showInfoWindow();
    }
    private String getSnippet(PlaceInfo placeInfo){

        String none = "N/A";
        return "Endereço: " + (placeInfo.getAddress() ==null? none: placeInfo.getAddress())
                + "\nTelefone: " +(placeInfo.getPhoneNumber() == null?none:placeInfo.getPhoneNumber())
                + "\nSite: " +(placeInfo.getWebsiteUri() == null? none : placeInfo.getWebsiteUri())
                + "\nAvaliação: " +  (placeInfo.getRating() == -1? none:placeInfo.getRating()) ;
    }

    @Override
    public boolean onMarkerClick(Marker marker) {

        return false;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // handle arrow click here
        if (item.getItemId() == android.R.id.home) {
            finish();
        }
        return super.onOptionsItemSelected(item);
    }
}
