package br.com.tcc.safeson.safeson.components;

import android.app.Activity;
import android.content.Context;
import android.util.Log;
import android.view.View;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

import br.com.tcc.safeson.safeson.MainActivity;
import br.com.tcc.safeson.safeson.adapter.MapInfoWindowAdapter;
import br.com.tcc.safeson.safeson.models.PlaceInfo;

public class CameraComponents {

    private static final String TAG = "MapsActivity";
    private GoogleMap mMap;
    private Marker mapMarker;
    private Context currentContext;
    private MainActivity activity;

    public CameraComponents (GoogleMap mMap, Marker mapMarker, Context currentContext, MainActivity activity){
        this.mMap = mMap;
        this.mapMarker = mapMarker;
        this.currentContext = currentContext;
        this.activity = activity;
    }

    public void moveCamera(LatLng latLng, float zoom, PlaceInfo placeInfo) {
        PlaceComponents placeComponents = new PlaceComponents();
        Log.d(TAG, "moveCamera: moving the camera to: lat: " + latLng.latitude + ", lng: " + latLng.longitude);
        this.mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(latLng, zoom));
        if (this.mapMarker != null)
            this.mapMarker.remove();
        this.mMap.setInfoWindowAdapter(new MapInfoWindowAdapter(this.currentContext));
        if(placeInfo != null){
            try {
                String snippet = placeComponents.getSnippet(placeInfo);
                MarkerOptions options = new MarkerOptions()
                        .position(latLng)
                        .title(placeInfo.getName())
                        .snippet(snippet);
                this.mapMarker = mMap.addMarker(options);
                activity.changeBtnVisibility(View.VISIBLE);

            }catch (NullPointerException e){
                Log.e(TAG, "moveCamera: Null placeInfo" + e.getMessage() );
            }

        }else{
            this.mMap.addMarker(new MarkerOptions().position(latLng));
        }

        if (this.mapMarker != null) this.mapMarker.showInfoWindow();
    }

    public void moveCamera(LatLng latLng, float zoom) {
        Log.d(TAG, "moveCamera: moving the camera to: lat: " + latLng.latitude + ", lng: " + latLng.longitude);
        //mMap.addMarker(new MarkerOptions().position(latLng));
        this.mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(latLng, zoom));
    }

    public Marker getMapMarker() {
        return mapMarker;
    }
}