package br.com.tcc.safeson.safeson.components;

import android.app.Activity;
import android.content.Context;
import android.location.Location;
import android.support.annotation.NonNull;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.Toast;

import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationListener;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;

import br.com.tcc.safeson.safeson.MainActivity;
import io.reactivex.Observable;
import io.reactivex.ObservableEmitter;

public class DeviceComponents extends MainActivity {

    private Context currentContext;
    private CameraComponents cameraComponents;

    public DeviceComponents(Context currentContext) {
        this.currentContext = currentContext;
    }

    public DeviceComponents(Context currentContext, CameraComponents cameraComponents) {
        this.currentContext = currentContext;
        this.cameraComponents = cameraComponents;
    }

    public static void hideKeyboard(Activity activity) {
        InputMethodManager imm = (InputMethodManager) activity.getSystemService(Activity.INPUT_METHOD_SERVICE);
        //Find the currently focused view, so we can grab the correct window token from it.
        View view = activity.getCurrentFocus();
        //If no view currently has focus, create a new one, just so we can grab a window token from it
        if (view == null) {
            view = new View(activity);
        }
        imm.hideSoftInputFromWindow(view.getWindowToken(), 0);
    }

    public void getDeviceLocation(Boolean mapPermissionGranted) {
        FusedLocationProviderClient mapFusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(currentContext);
        try {
            if (mapPermissionGranted) {
                Task location = mapFusedLocationProviderClient.getLastLocation();
                location.addOnCompleteListener(task -> {
                    if (task.isSuccessful()) {
                        Location currentLocation = (Location) task.getResult();

                        if (currentLocation != null && cameraComponents != null) {
                            cameraComponents.moveCamera(new LatLng(currentLocation.getLatitude(), currentLocation.getLongitude()), DEFAULT_ZOOM);
                        }
                    } else {
                        Toast.makeText(currentContext, "Unable to get current location", Toast.LENGTH_SHORT).show();
                    }
                });
            }
        } catch (SecurityException e) {
            System.out.println("getDeviceLocation: SecurityException: " + e.getMessage());
        }
    }

    public Observable<Location> getDeviceLocation() {
        return Observable.create((ObservableEmitter<Location> emitter) -> {
            FusedLocationProviderClient mapFusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(currentContext);

            mapFusedLocationProviderClient.getLastLocation()
                .addOnSuccessListener(this, location -> {
                    if (location != null && cameraComponents != null) {
                        cameraComponents.moveCamera(new LatLng(location.getLatitude(), location.getLongitude()), DEFAULT_ZOOM);
                        emitter.onNext(location);
                        emitter.onComplete();
                    }
                })
                .addOnFailureListener(this, e -> {
                    System.out.println("getDeviceLocation: SecurityException: " + e.getMessage());
                    emitter.onError(e);
                });
        });
    }
}
