package br.com.tcc.safeson.safeson.components;

import android.app.Activity;
import android.app.Fragment;
import android.app.FragmentTransaction;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.location.Address;
import android.location.Geocoder;
import android.location.Location;
import android.support.v4.graphics.drawable.RoundedBitmapDrawable;
import android.support.v4.graphics.drawable.RoundedBitmapDrawableFactory;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.widget.AdapterView;
import android.widget.AutoCompleteTextView;
import android.widget.ImageView;
import android.widget.Toast;

import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.common.api.PendingResult;
import com.google.android.gms.common.api.ResultCallback;
import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.location.places.AutocompletePrediction;
import com.google.android.gms.location.places.Place;
import com.google.android.gms.location.places.PlaceBuffer;
import com.google.android.gms.location.places.Places;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.LatLngBounds;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.android.gms.tasks.Task;
import com.google.maps.android.clustering.ClusterManager;
import com.squareup.picasso.Picasso;

import org.joda.time.format.DateTimeFormat;
import org.joda.time.format.DateTimeFormatter;

import java.io.IOException;
import java.net.URL;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

import br.com.tcc.safeson.safeson.MainActivity;
import br.com.tcc.safeson.safeson.R;
import br.com.tcc.safeson.safeson.adapter.PlaceAutocompleteAdapter;
import br.com.tcc.safeson.safeson.dialog.TipoTrajetoDialog;
import br.com.tcc.safeson.safeson.models.Alert;
import br.com.tcc.safeson.safeson.models.ClusterMarker;
import br.com.tcc.safeson.safeson.models.Coordenada;
import br.com.tcc.safeson.safeson.models.Panico;
import br.com.tcc.safeson.safeson.models.PlaceInfo;
import br.com.tcc.safeson.safeson.models.TipoTrajeto;
import br.com.tcc.safeson.safeson.models.User;
import br.com.tcc.safeson.safeson.util.ClusterManagerRendererUtil;
import butterknife.BindView;
import io.reactivex.Observable;
import io.reactivex.schedulers.Schedulers;

public class MapComponents extends MainActivity implements GoogleMap.OnMarkerClickListener {

    public static final float DEFAULT_ZOOM = 15f;

    private static final String TAG = "MapsActivity";

    private static final LatLngBounds LAT_LNG_BOUNDS = new LatLngBounds(new LatLng(-40, -168), new LatLng(71, 136));
    private PlaceAutocompleteAdapter mapPlaceAutocompleteAdapter;
    private PlaceInfo mapPlace;

    private GoogleMap mMap;
    private Marker mapMarker;
    private Context currentContext;
    private Context mapContext;
    private CameraComponents cameraComponents;
    private GoogleApiClient googleApiClient;
    private Activity activity;
    private ClusterManager mClusterManager;
    private ClusterManagerRendererUtil mClusterManagerRenderer;
    private ArrayList<ClusterMarker> mClusterMarkers = new ArrayList<>();

    private DeviceComponents deviceComponents;

    // Static methods
    public static void initMap(OnMapReadyCallback onMapReadyCallback, SupportMapFragment mapFragment) {
        mapFragment.getMapAsync(onMapReadyCallback);
    }

    public MapComponents(GoogleMap mMap, Marker mapMarker, Context currentContext, Context mapContext, CameraComponents cameraComponents, GoogleApiClient googleApiClient, Activity activity, DeviceComponents deviceComponents) {
        this.mMap = mMap;
        this.mapMarker = mapMarker;
        this.currentContext = currentContext;
        this.cameraComponents = cameraComponents;
        this.mapContext = mapContext;
        this.googleApiClient = googleApiClient;
        this.activity = activity;
        this.deviceComponents = deviceComponents;

        this.mMap.setOnMarkerClickListener(this);
    }

    public Activity getActivity() {
        return this.activity;
    }


    @Override
    public boolean onMarkerClick(Marker marker) {
        marker.hideInfoWindow();
        return false;
    }

    public void initSearch(String tag, Boolean mapPermissionGranted, AutoCompleteTextView mapSearchText, ImageView mGps, PlaceInfo mapPlace) {
        mGps.setOnClickListener(view -> {
            //deviceComponents.hideKeyboard();
            deviceComponents.getDeviceLocation(mapPermissionGranted);
        });

        mapSearchText.setOnItemClickListener(mAutocompleteClickListener);
        mapPlaceAutocompleteAdapter = new PlaceAutocompleteAdapter(currentContext, googleApiClient, LAT_LNG_BOUNDS, null);
        mapSearchText.setAdapter(mapPlaceAutocompleteAdapter);

        mapSearchText.setOnEditorActionListener((textView, actionId, keyEvent) -> {
            //deviceComponents.hideKeyboard();
            if (actionId == EditorInfo.IME_ACTION_SEARCH
                    || actionId == EditorInfo.IME_ACTION_DONE
                    || keyEvent.getAction() == KeyEvent.ACTION_DOWN
                    || keyEvent.getAction() == KeyEvent.KEYCODE_ENTER) {

                    searchLocation(tag, mapSearchText, mapPlace);
            }
            return false;
        });
    }

    public void searchLocation(String tag, AutoCompleteTextView mapSearchText, PlaceInfo placeInfo) {
        String searchTerm = mapSearchText.getText().toString();
        Geocoder geocoder = new Geocoder(currentContext);
        List<Address> list = new ArrayList<>();
        try {
            list = geocoder.getFromLocationName(searchTerm, 1);
            mapPlace = new PlaceInfo();
            mapPlace.setName(list.get(0).getFeatureName());
            mapPlace.setAddress(list.get(0).getAddressLine(0));
            mapPlace.setPhoneNumber(list.get(0).getPhone());
            mapPlace.setRating(-1);
        } catch (IOException e) {
            Log.e(tag, "searchLocation: IOException" + e.getMessage());
        }
        if (list.size() > 0) {
            Address address = list.get(0);
            cameraComponents.moveCamera(new LatLng(address.getLatitude(), address.getLongitude()), DEFAULT_ZOOM, mapPlace);
        }
    }

    public PlaceInfo searchLocationByLatLng(LatLng latLng, String tag) {
        Geocoder geocoder = new Geocoder(currentContext);
        List<Address> list = new ArrayList<>();
        try {
            list = geocoder.getFromLocation(latLng.latitude, latLng.longitude, 1);

            if (list.isEmpty()) return mapPlace;

            mapPlace = new PlaceInfo();
            mapPlace.setName(list.get(0).getFeatureName());
            mapPlace.setAddress(list.get(0).getAddressLine(0));
            mapPlace.setPhoneNumber(list.get(0).getPhone());
            mapPlace.setLatLng(latLng);
            mapPlace.setRating(-1);
        } catch (IOException e) {
            Log.e(tag, "searchLocation: IOException" + e.getMessage());
        }

        if (list.size() > 0) {
            Address address = list.get(0);
            cameraComponents.moveCamera(new LatLng(address.getLatitude(), address.getLongitude()), DEFAULT_ZOOM);
        }

        return mapPlace;
    }

    private AdapterView.OnItemClickListener mAutocompleteClickListener = new AdapterView.OnItemClickListener() {
        @Override
        public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
            DeviceComponents.hideKeyboard(activity);
            final AutocompletePrediction item = mapPlaceAutocompleteAdapter.getItem(i);
            final String placeId = item.getPlaceId();

            PendingResult<PlaceBuffer> placeResult = Places.GeoDataApi.getPlaceById(googleApiClient, placeId);
            placeResult.setResultCallback(mapUpdatePlaceDetailsCallBack);
        }
    };
    private ResultCallback<PlaceBuffer> mapUpdatePlaceDetailsCallBack = places -> {
        if (!places.getStatus().isSuccess()) {
            Log.d(TAG, "onResult: fail query complete: " + places.getStatus().toString());
            places.release();
            return;
        }
        final Place place = places.get(0);

        try {
            mapPlace = new PlaceInfo();
            mapPlace.setName(place.getName().toString());
            mapPlace.setAddress(place.getAddress().toString());
            mapPlace.setPhoneNumber(place.getPhoneNumber().toString());
            mapPlace.setId(place.getId());
            mapPlace.setWebsiteUri(place.getWebsiteUri());
            mapPlace.setLatLng(place.getLatLng());
            mapPlace.setRating(place.getRating());
            mapPlace.setAttributions(place.getAttributions().toString());

        } catch (NullPointerException e) {
            Log.e(TAG, "Places param null: " + e.getMessage());
        }

        cameraComponents.moveCamera(mapPlace.getLatLng(), DEFAULT_ZOOM, mapPlace);
        places.release();


    };

    public void addMapMarkers(Context context, Alert alert){

        if(mMap != null){

            if(mClusterManager == null){
                mClusterManager = new ClusterManager<ClusterMarker>(context, mMap);
            }
            if(mClusterManagerRenderer == null){
                mClusterManagerRenderer = new ClusterManagerRendererUtil(
                        context,
                        mMap,
                        mClusterManager
                );
                mClusterManager.setRenderer(mClusterManagerRenderer);
            }


            try{
                String snippet = "";
                int alertIcon;
                snippet = alert.descricao;
                switch (alert.tipoId) {
                    case 1:
                        alertIcon = R.drawable.ic_robbery;
                        break;
                    case 2:
                        alertIcon = R.drawable.ic_theft;
                        break;
                    case 3:
                        alertIcon = R.drawable.ic_harassment;
                        break;
                    case 4:
                        alertIcon = R.drawable.ic_kidnap;

                        break;
                    case 5:
                        alertIcon = R.drawable.ic_animal;
                        break;
                    case 6:
                        alertIcon = R.drawable.ic_luminosity;
                        break;
                    default: alertIcon = R.drawable.ic_others;
                }
                DateFormat df = new SimpleDateFormat("dd/MM/yyyy HH:mm");
                String sdt = df.format(alert.dataCriacao);
                ClusterMarker newClusterMarker = new ClusterMarker(
                        new LatLng(alert.coordenada.latitude, alert.coordenada.longitude),
                        alert.nome + " - " + sdt ,
                        snippet,
                        alertIcon
                );

                mClusterManager.addItem(newClusterMarker);
                mClusterMarkers.add(newClusterMarker);

            }catch (NullPointerException e){
                Log.e(TAG, "addMapMarkers: NullPointerException: " + e.getMessage() );
            }


            mClusterManager.cluster();
        }
    }

    public void addPanicoMarker(Context context, Panico panico, User usuario, PlaceInfo mapPlace) {
        if(mMap != null){
            if(mClusterManager == null){
                mClusterManager = new ClusterManager<ClusterMarker>(context, mMap);
            }
            if(mClusterManagerRenderer == null){
                mClusterManagerRenderer = new ClusterManagerRendererUtil(
                    context,
                    mMap,
                    mClusterManager
                );
                mClusterManager.setRenderer(mClusterManagerRenderer);
            }

            try{
                String snippet = "";
                int alertIcon = R.drawable.ic_panic;
                snippet = mapPlace.getAddress() + (mapPlace.getPhoneNumber() != null ? " / " + mapPlace.getPhoneNumber() : "");
                DateFormat df = new SimpleDateFormat("dd/MM/yyyy HH:mm");
                String sdt = df.format(panico.data);
                ClusterMarker newClusterMarker = new ClusterMarker(
                        new LatLng(panico.coordenada.latitude, panico.coordenada.longitude),
                            usuario.nome + " Está em perigo! " + sdt,
                        snippet,
                        alertIcon
                );

                mClusterManager.addItem(newClusterMarker);
                mClusterMarkers.add(newClusterMarker);

            }catch (NullPointerException e){
                Log.e(TAG, "addPanico: NullPointerException: " + e.getMessage() );
            }

            mClusterManager.cluster();
        }
    }


    public Marker updateUserLocation(User criador, Coordenada coordenada, Marker person) {
        if(person != null){
            person.remove();
        }

        return mMap.addMarker(new MarkerOptions()
                .position(new LatLng(coordenada.latitude, coordenada.longitude))
                .title(criador.nome)
                .icon(BitmapDescriptorFactory.fromBitmap(criador.getRoundedImg())));
    }
}
