package br.com.tcc.safeson.safeson.components;

import android.content.Context;
import android.graphics.Color;
import android.location.Location;
import android.os.Handler;
import android.os.Looper;
import android.support.annotation.Nullable;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AlertDialog;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.model.Dash;
import com.google.android.gms.maps.model.Dot;
import com.google.android.gms.maps.model.Gap;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.LatLngBounds;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.android.gms.maps.model.PatternItem;
import com.google.android.gms.maps.model.Polyline;
import com.google.android.gms.maps.model.PolylineOptions;
import com.google.maps.DirectionsApiRequest;
import com.google.maps.GeoApiContext;
import com.google.maps.internal.PolylineEncoding;
import com.google.maps.model.DirectionsLeg;
import com.google.maps.model.DirectionsResult;
import com.google.maps.model.DirectionsRoute;
import com.google.maps.model.DirectionsStep;
import com.google.maps.model.TransitMode;
import com.google.maps.model.TravelMode;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Random;

import br.com.tcc.safeson.safeson.R;
import br.com.tcc.safeson.safeson.models.Coordenada;
import br.com.tcc.safeson.safeson.models.PolylineData;
import br.com.tcc.safeson.safeson.models.Trajeto;
import io.reactivex.schedulers.Schedulers;

public class RouteComponents implements GoogleMap.OnPolylineClickListener {

    public static final PatternItem DASH = new Dash(20);
    public static final PatternItem GAP = new Gap(20);
    public static final List<PatternItem> PATTERN_POLYGON_ALPHA = Arrays.asList(GAP, DASH);

    private boolean creatingRoute = false;
    private GoogleMap mMap;
    private Marker mapMarker;
    private Context currentContext;
    private GeoApiContext mapGeoApiContext;
    private ArrayList<PolylineData> mapPolylineData;
    private DeviceComponents deviceComponents;
    private PolylineData userPolyline;
    public int routeId = 0;

    public RouteComponents(GoogleMap mMap, Marker mapMarker, Context currentContext, GeoApiContext mapGeoApiContext, DeviceComponents deviceComponents) {
        this.mMap = mMap;
        this.mapMarker = mapMarker;
        this.currentContext = currentContext;
        this.mapGeoApiContext = mapGeoApiContext;
        this.mapPolylineData = new ArrayList<>();

        this.deviceComponents = deviceComponents;

        this.mMap.setOnPolylineClickListener(this);
    }

    public void zoomRoute(List<LatLng> lsLatLngsRoute){
        if (mMap != null || lsLatLngsRoute != null || !lsLatLngsRoute.isEmpty()){
            LatLngBounds.Builder boundsBuilder = new LatLngBounds.Builder();
            for(LatLng latLanLngPoint: lsLatLngsRoute)
                boundsBuilder.include(latLanLngPoint);

            int routePadding = 220;
            LatLngBounds latLngBounds = boundsBuilder.build();

            mMap.animateCamera(
                CameraUpdateFactory.newLatLngBounds(latLngBounds, routePadding),
                600,
                null
            );
        }

    }

    public int getContexColor(int color) {
        return ContextCompat.getColor(currentContext,color);
    }

    public void setRouteOnMap(final DirectionsResult result, TravelMode mode){
        creatingRoute = true; // verificar necessidade
        new Handler(Looper.getMainLooper()).post(() -> {
            if(mapPolylineData.size() > 0){
                for (PolylineData polylineData: mapPolylineData){
                    for(Polyline polyline: polylineData.getPolyline())
                        polyline.remove();
                }
                mapPolylineData.clear();
                mapPolylineData = new ArrayList<>();
            }
            double duration = 999999999;
            PolylineOptions polylineOptions;
            Polyline selected = null;

            for (DirectionsRoute route: result.routes){
                List<com.google.maps.model.LatLng> decodeFullPath  = PolylineEncoding.decode(route.overviewPolyline.getEncodedPath());

                List<LatLng> newDecodedFullPath = new ArrayList<>();
                for (com.google.maps.model.LatLng latLng: decodeFullPath){
                    newDecodedFullPath.add(new LatLng(latLng.lat, latLng.lng));
                }
                polylineOptions = new PolylineOptions().addAll(newDecodedFullPath); // mudar nome para fullpath

                ArrayList<Polyline> polylineList = new ArrayList<>();
                ArrayList<TravelMode> travelModes = new ArrayList<>();
                ArrayList<List<LatLng>> pontosList = new ArrayList<>();

                Polyline polyline;
                if (mode == TravelMode.TRANSIT) {
                    List<LatLng> newDecodedPath = new ArrayList<>();
                    TravelMode travelMode = null;

                    for (DirectionsStep step : route.legs[0].steps) {
                        List<com.google.maps.model.LatLng> decodePath = PolylineEncoding.decode(step.polyline.getEncodedPath());
                        for (com.google.maps.model.LatLng latLng : decodePath) {
                            newDecodedPath.add(new LatLng(latLng.lat, latLng.lng));
                        }
                        if (travelMode != step.travelMode) {
                            if (step.travelMode == TravelMode.WALKING)
                                polyline = mMap.addPolyline(new PolylineOptions().addAll(newDecodedPath).pattern(PATTERN_POLYGON_ALPHA));
                            else
                                polyline = mMap.addPolyline(new PolylineOptions().addAll(newDecodedPath));
                            polyline.setColor(getContexColor(R.color.darkGrey));
                            polyline.setClickable(true);

                            pontosList.add(newDecodedPath);
                            polylineList.add(polyline);
                            travelMode = step.travelMode;
                            travelModes.add(step.travelMode);
                            newDecodedPath = new ArrayList<>();
                            double tempDuration = route.legs[0].duration.inSeconds;
                            if (tempDuration < duration) {
                                duration = tempDuration;
                                selected = polyline;
                            }
                        }
                    }
                }else{
                    polyline = mMap.addPolyline(polylineOptions);
                    polyline.setColor(getContexColor(R.color.darkGrey));
                    polyline.setClickable(true);
                    polylineList.add(polyline);

                    pontosList.add(polyline.getPoints());
                    travelModes.add(mode);

                    double tempDuration = route.legs[0].duration.inSeconds;
                    if (tempDuration < duration) {
                        duration = tempDuration;
                        selected = polyline;
                    }
                }
                mapPolylineData.add(new PolylineData(polylineList, pontosList, route.legs[0], polylineOptions, travelModes, mode));
                onPolylineClick(selected);
                zoomRoute(polylineOptions.getPoints());

            }
        });
    }

    public void displayRoute(Trajeto t){
        for (int i = 0; i < t.pontos.getPontosList().size(); i++) {
            List<LatLng> ponto = t.pontos.getPontosList().get(i);

            Polyline polyline;
            if (t.pontos.getTravelMode().get(i).equals(TravelMode.WALKING)) {
                polyline = mMap.addPolyline(
                    new PolylineOptions()
                        .addAll(ponto)
                        .pattern(PATTERN_POLYGON_ALPHA)
                );
            } else {
                polyline = mMap.addPolyline(new PolylineOptions().addAll(ponto));
            }

            Random r = new Random();

            polyline.setColor(
                Color.rgb(
                    r.nextInt(255), r.nextInt(255), r.nextInt(255)
                )
            );
        }
    }


    public void calculateRoute(Coordenada destino, TravelMode mode){
        com.google.maps.model.LatLng destination = new com.google.maps.model.LatLng(destino.latitude, destino.longitude);
        DirectionsApiRequest directions = new DirectionsApiRequest(mapGeoApiContext);

        directions.alternatives(true);

        deviceComponents
            .getDeviceLocation()
            .observeOn(Schedulers.single())
            .subscribe(location -> {
                com.google.maps.model.LatLng orig = new com.google.maps.model.LatLng(
                    location.getLatitude(), location.getLongitude()
                );

                directions.origin(orig);
                directions.mode(mode);
                directions.transitMode(TransitMode.BUS);
                directions.destination(destination);

                directions.setCallback(new com.google.maps.PendingResult.Callback<DirectionsResult>() {
                    @Override
                    public void onResult(DirectionsResult result) {
                        setRouteOnMap(result, mode);
                    }

                    @Override
                    public void onFailure(Throwable e) {
                        System.out.println("Erro colocando rota no mapa -> " + e);
                    }
                });
            });

    }

    @Override
    public void onPolylineClick(Polyline polyline) {
        for (int i =0; i < mapPolylineData.size(); i++){
            for(Polyline polyItem: mapPolylineData.get(i).getPolyline()){
                if(polyline.getId().equals(polyItem.getId())){
                    routeId = i;
                    break;
                }
                polyItem.setColor(getContexColor(R.color.darkGrey));
                polyItem.setZIndex(0);
            }
        }
        for(Polyline polyItem: mapPolylineData.get(routeId).getPolyline()){

            polyItem.setColor(getContexColor(R.color.blueLine));
            polyItem.setZIndex(1);

            LatLng endLocation = new LatLng(mapPolylineData.get(routeId).getLeg().endLocation.lat,
                    mapPolylineData.get(routeId).getLeg().endLocation.lng);
            Marker marker = mMap.addMarker(
                    new MarkerOptions().position(endLocation).title("Viagem #"+ (routeId+1)).snippet(
                            "Tempo de Viagem: "  +  mapPolylineData.get(routeId).getLeg().duration
                                    + "\nHorario estimado: " + mapPolylineData.get(routeId).getLeg().arrivalTime
                                    + "\nDistacia: " +  mapPolylineData.get(routeId).getLeg().distance));

            marker.showInfoWindow();
        }

    }

    public PolylineData setMySelectedRoute() {
        userPolyline = mapPolylineData.get(routeId);
        if(mapPolylineData.size() > 0){
            for (PolylineData polylineData: mapPolylineData){
                for(Polyline polyline: polylineData.getPolyline())
                    polyline.remove();
            }
            mapPolylineData.clear();
            mapPolylineData = new ArrayList<>();
        }
        ArrayList<Polyline> polyline = userPolyline.getPolyline();
        for(int i = 0; i < polyline.size(); i++){
            Polyline polylineOptions;
            if (userPolyline.getTravelMode().get(i) == TravelMode.WALKING)
                polylineOptions = mMap.addPolyline(new PolylineOptions().addAll(polyline.get(i).getPoints()).pattern(PATTERN_POLYGON_ALPHA));
            else
                polylineOptions = mMap.addPolyline(new PolylineOptions().addAll(polyline.get(i).getPoints()));
            polylineOptions.setColor(getContexColor(R.color.blueLine));
            polylineOptions.setZIndex(1);
        }

        return userPolyline;

    }
}
