package br.com.tcc.safeson.safeson.models;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;

import java.io.InputStream;
import java.io.Serializable;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;

import io.reactivex.Observable;

public class User implements Serializable {
    public int id;
    public String nome;
    public String email;
    public String imgUrl;
    public String socialId;
    public boolean created;
    private Bitmap bitmap;
    private Bitmap roundedImg;

    public User(String nome, String email, String imgUrl, String socialId, boolean created) {
        this.nome = nome;
        this.email = email;
        this.imgUrl = imgUrl;
        this.socialId = socialId;
        this.created = created;
    }

    public User(int id, String nome, String email, String imgUrl, String socialId, boolean created) {
        this.id = id;
        this.nome = nome;
        this.email = email;
        this.imgUrl = imgUrl;
        this.socialId = socialId;
        this.created = created;
    }

    public User(String socialId) {
        this.socialId = socialId;
    }

    private void setBitmap(Bitmap bmp) {
        this.bitmap = bmp;
    }

    public void setRoundedImg(Bitmap img) {
        this.roundedImg = getCircleBitmap(img);
    }

    public Bitmap getRoundedImg() {
        return this.roundedImg;
    }

    public Observable getImg() {
        return Observable.create(emitter -> {
            if (this.bitmap != null) {
                emitter.onNext(this.bitmap);
                emitter.onComplete();
                return;
            }

            try {
                Thread t = new Thread(() -> {
                    final URL url;
                    try {
                        url = new URL(this.imgUrl);
                        emitter.onNext(BitmapFactory.decodeStream(url.openConnection().getInputStream()));
                        emitter.onComplete();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                });
                t.start();
            } catch (Exception e) {
                emitter.onError(e);
            }
        });
    }

    private Bitmap getCircleBitmap(Bitmap bitmap) {
        final Bitmap output = Bitmap.createBitmap(bitmap.getWidth(),
                bitmap.getHeight(), Bitmap.Config.ARGB_8888);
        final Canvas canvas = new Canvas(output);

        final int color = Color.RED;
        final Paint paint = new Paint();
        final Rect rect = new Rect(0, 0, bitmap.getWidth(), bitmap.getHeight());
        final RectF rectF = new RectF(rect);

        paint.setAntiAlias(true);
        canvas.drawARGB(0, 0, 0, 0);
        paint.setColor(color);
        canvas.drawOval(rectF, paint);

        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.SRC_IN));
        canvas.drawBitmap(bitmap, rect, rect, paint);

        bitmap.recycle();

        return output;
    }

    @Override
    public String toString() {
        return  nome;
    }
}
