package br.com.tcc.safeson.safeson.route;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Build;
import android.os.Vibrator;
import android.support.v4.app.NotificationCompat;
import android.support.v4.app.NotificationManagerCompat;

import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;


import br.com.tcc.safeson.safeson.MainActivity;
import br.com.tcc.safeson.safeson.R;
import br.com.tcc.safeson.safeson.actions.EventRoute.EventBroadcastCoordinatesMessage;
import br.com.tcc.safeson.safeson.actions.EventRoute.EventBroadcastCoordinatesResult;
import br.com.tcc.safeson.safeson.components.MapComponents;
import br.com.tcc.safeson.safeson.models.Coordenada;
import br.com.tcc.safeson.safeson.models.Panico;
import br.com.tcc.safeson.safeson.models.PlaceInfo;
import br.com.tcc.safeson.safeson.models.Trajeto;
import br.com.tcc.safeson.safeson.socket.BroadcastEvent;
import br.com.tcc.safeson.safeson.socket.ResultObject;
import br.com.tcc.safeson.safeson.socket.SocketConnection;
import io.reactivex.Observable;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.schedulers.Schedulers;

public class RouteEventsListener {
    /**
     * Todos objetos estaticos dos eventos que serão ouvidos
     */
    private BroadcastEvent myCoordinatesEvent;
    private BroadcastEvent panicEvent;
    private BroadcastEvent userLeftRouteEvent;

    private Trajeto trajeto;
    private MapComponents mapComponents;
    private Marker person;

    public RouteEventsListener(Trajeto t, MapComponents mapComponents) {
        this.trajeto = t;
        this.mapComponents = mapComponents;
    }

    public Observable subscribeAll() {
        return Observable.create(emitter -> {
            this.trajeto.criador
                .getImg()
                .observeOn(Schedulers.newThread())
                .subscribe(
                    imagem -> {
                        Bitmap smallMarker = Bitmap.createScaledBitmap((Bitmap) imagem,100, 100, false);

                        this.trajeto.criador.setRoundedImg(smallMarker);

                        System.out.println("Inscrevendo eventos para rotas");

                        myCoordinatesEvent = new BroadcastEvent("my.coordinates", EventBroadcastCoordinatesResult.class);
                        panicEvent = new BroadcastEvent("panic.add", Panico.class);
                        userLeftRouteEvent = new BroadcastEvent("route.userLeft", Object.class);

                        // Subscribe events
                        myCoordinatesSubscribe();
                        panicoSubscribe();
                        userLeftRouteSubscribe();

                        emitter.onNext(true);
                        emitter.onComplete();
                    },
                    (err) -> emitter.onError(new Exception(err.toString()))
                );
        });

    }

    public void setPersonMarker(Marker person) {
        this.person = person;
    }

    public Marker getPersonMarker() {
        return this.person;
    }

    private void myCoordinatesSubscribe() {
        myCoordinatesEvent
            .listen()
            .observeOn(Schedulers.newThread())
            .subscribe(
                res -> {
                    if (!myCoordinatesEvent.getReceiverKey().equals(res.broadcastReceiver)) return;

                    Coordenada userCoordinates = ((EventBroadcastCoordinatesResult) res.result).coordenada;

                    if (res.key.equals(trajeto.uuid)) {
                        mapComponents.getActivity().runOnUiThread(() -> {
                            setPersonMarker(mapComponents.updateUserLocation(trajeto.criador, userCoordinates, getPersonMarker()));
                        });
                    }
                },
                err -> {
                    System.out.println("Erro mostrando as coordenadas do usuario");
                    System.out.println(err);
                }
            );
    }
    private void panicoSubscribe() {
        panicEvent
            .listen()
            .observeOn(Schedulers.newThread())
            .subscribe(
                (res) -> {
                    if (!panicEvent.getReceiverKey().equals(res.broadcastReceiver)) return;
                    Panico panic = (Panico) res.result;

                    if (res.key.equals(panic.trajetoUuid)) {
                        mapComponents.getActivity().runOnUiThread(() -> {
                            PlaceInfo mapPlace = mapComponents.searchLocationByLatLng(
                                    new LatLng(panic.coordenada.latitude, panic.coordenada.longitude), "TAG_LOCAL_PANICO");
                            mapComponents.addPanicoMarker(mapComponents.getActivity(), panic, this.trajeto.criador, mapPlace);

                            NotificationManager mNotificationManager;
                            Context mContext = mapComponents.getActivity();

                            NotificationCompat.Builder mBuilder =
                                    new NotificationCompat.Builder(mContext.getApplicationContext(), "notify_001");
                            Intent ii = new Intent(mContext.getApplicationContext(), MainActivity.class);
                            PendingIntent pendingIntent = PendingIntent.getActivity(mContext, 0, ii, 0);

                            NotificationCompat.BigTextStyle bigText = new NotificationCompat.BigTextStyle();
                            bigText.bigText(this.trajeto.criador.nome + " Precisa da sua ajuda!");
                            bigText.setBigContentTitle(this.trajeto.criador.nome + " Está em perigo!");
                            bigText.setSummaryText(this.trajeto.criador.nome + " Entrou em pânico!");

                            mBuilder.setContentIntent(pendingIntent);
                            mBuilder.setSmallIcon(R.drawable.ic_panic);
                            mBuilder.setContentTitle(this.trajeto.criador.nome + " Está em perigo!");
                            mBuilder.setContentText("PÂNICO! Seu amigo está em perigo");
                            mBuilder.setPriority(Notification.PRIORITY_MAX);
                            mBuilder.setStyle(bigText);

                            mNotificationManager =
                                    (NotificationManager) mContext.getSystemService(Context.NOTIFICATION_SERVICE);

                            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                                String channelId = "YOUR_CHANNEL_ID";
                                NotificationChannel channel = new NotificationChannel(channelId,
                                        "Panico",
                                        NotificationManager.IMPORTANCE_DEFAULT);
                                mNotificationManager.createNotificationChannel(channel);
                                mBuilder.setChannelId(channelId);
                            }

                            mNotificationManager.notify(0, mBuilder.build());

                            final int time = 3000;
                            Vibrator v = (Vibrator) this.mapComponents.getActivity().getSystemService(Context.VIBRATOR_SERVICE);
                            v.vibrate(time);
                        });
                    }
                },
                (err) -> {
                    System.out.println("Errou");
                    System.out.println(err);
                });
    }
    private void userLeftRouteSubscribe() {
        userLeftRouteEvent
            .listen()
            .observeOn(Schedulers.newThread())
            .subscribe(
                (res) -> {
                    if (!userLeftRouteEvent.getReceiverKey().equals(res.broadcastReceiver)) return;

                    mapComponents.getActivity().runOnUiThread(() -> {
                        NotificationManager mNotificationManager;
                        Context mContext = mapComponents.getActivity();

                        NotificationCompat.Builder mBuilder =
                                new NotificationCompat.Builder(mContext.getApplicationContext(), "notify_001");
                        Intent ii = new Intent(mContext.getApplicationContext(), MainActivity.class);
                        PendingIntent pendingIntent = PendingIntent.getActivity(mContext, 0, ii, 0);

                        NotificationCompat.BigTextStyle bigText = new NotificationCompat.BigTextStyle();
                        bigText.bigText("Seu amigo(a) já saiu da rota faz um tempo");
                        bigText.setBigContentTitle(this.trajeto.criador.nome + " Saiu do trajeto já faz um tempo");
                        bigText.setSummaryText(this.trajeto.criador.nome + " Saiu do trajeto já faz um tempo");

                        mBuilder.setContentIntent(pendingIntent);
                        mBuilder.setSmallIcon(R.drawable.ic_panic);
                        mBuilder.setContentTitle(this.trajeto.criador.nome + " Saiu do trajeto já faz um tempo");
                        mBuilder.setContentText("Seu amigo(a) já saiu da rota faz um tempo");
                        mBuilder.setPriority(Notification.PRIORITY_MAX);
                        mBuilder.setStyle(bigText);

                        mNotificationManager =
                                (NotificationManager) mContext.getSystemService(Context.NOTIFICATION_SERVICE);

                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                            String channelId = "YOUR_CHANNEL_ID";
                            NotificationChannel channel = new NotificationChannel(channelId,
                                    "Panico",
                                    NotificationManager.IMPORTANCE_DEFAULT);
                            mNotificationManager.createNotificationChannel(channel);
                            mBuilder.setChannelId(channelId);
                        }

                        mNotificationManager.notify(0, mBuilder.build());
                    });
                },
                (err) -> {
                    System.out.println("Errou");
                    System.out.println(err);
                });
    }
}
