package br.com.tcc.safeson.safeson.socket;

import com.google.gson.Gson;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.UUID;

import javax.xml.transform.Result;

import io.reactivex.Observable;
import io.reactivex.ObservableEmitter;

public class BroadcastEvent {
    private static ArrayList<BroadcastEvent> broadcasts = new ArrayList<>();

    /**
     * Emit broadcasted message from event and parse the response
     * @param res Object received from event
     */
    public static void emitBroadcastMessage(ResultObject res) {
        String message = res.event;

        for (BroadcastEvent broadcast : broadcasts) {
            if (!broadcast.getMessage().equals(message)) continue;
            if (broadcast.getEmitter() == null) continue;
            if (broadcast.getParser() == null) continue;

            if (res.result != null && broadcast.getParser() != null) {
                Gson gson = new Gson();
                res.result = gson.fromJson(gson.toJson(res.result), broadcast.getParser());
            }

            res.setBroadcastReceiver(broadcast.getReceiverKey());

            if (res.error) {
                broadcast.getEmitter().onError(new Exception(res.msg));
            } else {
                broadcast.getEmitter().onNext(res);
            }
        }
    }

    private String message;
    private Class parser;
    private ObservableEmitter<ResultObject> emitter;
    private String receiverKey;

    /**
     * Listen to a specific broadcast event
     * @param message Which broadcast event to listen
     * @param parser Result class object
     * @return Observable that handles the event emission
     */
    public BroadcastEvent(String message, Class parser) {
        this.message = message;
        this.parser = parser;
        this.receiverKey = String.valueOf(UUID.randomUUID());

        broadcasts.add(this);
    }

    public Observable<ResultObject> listen() {
        return Observable.create(emitter -> this.emitter = emitter);
    }

    /**
     * Dispose of some broadcast listener
     * @param message
     */
    public void dispose(String message) {
        this.emitter.onComplete();
    }

    /**
     * @param event Name of the event
     * @return If the client is listening to the event
     */
    public static boolean isListening(String event) {
        for (BroadcastEvent broadcast : broadcasts) {
            boolean listening = broadcast.getMessage().equals(event);

            if (listening) return true;
        }
        return false;
    }


    // Getters
    public String getMessage() {
        return message;
    }

    public Class getParser() {
        return parser;
    }

    public String getReceiverKey() {
        return receiverKey;
    }

    public ObservableEmitter<ResultObject> getEmitter() {
        return emitter;
    }
}
